@@ -206,7 +206,7 @@ class Download {
 
 public:
 
-	Download();
+	Download(bool keep);
 	~Download();
 
 	void
@@ -263,6 +263,8 @@ private:
 	 */
 	lt::torrent_handle m_torrent_handle;
 
+	bool m_keep;
+
 	Queue m_queue;
 
 	void
