@@ -67,7 +67,7 @@ MagnetMetadataOpen(vlc_object_t *p_this)
 
 	access_sys_t *p_sys = (access_sys_t *) malloc(sizeof (access_sys_t));
 
-	Download d;
+	Download d(get_keep_files(p_this));
 
 	try {
 		// Parse metadata
