@@ -119,6 +119,23 @@ has_extension(std::string file, std::string ext)
 	return *filei == '.';
 }
 
+static bool
+is_subtitle_of(std::string video, std::string subtitle) {
+	size_t begin = video.find_last_of('/');
+	if (begin == std::string::npos)
+		begin = 0;
+
+	std::string base;
+
+	size_t end = video.find_last_of('.');
+	if (end == std::string::npos)
+		base = video.substr(begin);
+	else
+		base = video.substr(begin, end - begin);
+
+	return subtitle.find(base) != std::string::npos;
+}
+
 static void
 build_playlist(stream_t *p_demux, input_item_node_t *p_subitems, Download& d)
 {
@@ -155,6 +172,17 @@ build_playlist(stream_t *p_demux, input_item_node_t *p_subitems, Download& d)
 	if (get_add_image_files((vlc_object_t *) p_demux))
 		ext.insert(ext.end(), image_ext.begin(), image_ext.end());
 
+	int num_media_files = 0;
+
+	for (auto f : d.get_files()) {
+		for (auto e : ext) {
+			if (has_extension(f.first, e)) {
+				num_media_files++;
+				break;
+			}
+		}
+	}
+
 	for (auto f : d.get_files()) {
 		bool add = false;
 
@@ -172,6 +200,25 @@ build_playlist(stream_t *p_demux, input_item_node_t *p_subitems, Download& d)
 
 		input_item_t *p_input = input_item_New(mrl.c_str(), title.c_str());
 
+		for (auto s : d.get_files()) {
+			enum slave_type type;
+
+			if (!input_item_slave_GetType(s.first.c_str(), &type))
+				continue;
+
+			if (type != SLAVE_TYPE_SPU)
+				continue;
+
+			// If we only have one media file to play we add all subtitles
+			if (num_media_files != 1 && !is_subtitle_of(f.first, s.first))
+				continue;
+
+			std::string smrl = "bittorrent://" + path + "?" + s.first;
+
+			input_item_AddSlave(p_input, input_item_slave_New(smrl.c_str(),
+				type, SLAVE_PRIORITY_MATCH_NONE));
+		}
+
 		input_item_CopyOptions(p_input, p_current_input);
 		input_item_node_AppendItem(p_subitems, p_input);
 		input_item_Release(p_input);
@@ -191,7 +238,7 @@ MetadataReadDir(stream_t *p_demux, input_item_node_t *p_subitems)
 		return -1;
 	}
 
-	Download d;
+	Download d(get_keep_files((vlc_object_t *) p_demux));
 
 	try {
 		// Parse metadata
